View source: R/Functions_L1_Pop.R
| combineBeeGametes | R Documentation |
Level 1 function that produces diploid offspring from a mated queen.
Queen is diploid, while drones are double haploids so we use AlphaSimR diploid
functionality to make this cross, but since drones are double haploids we
get the desired outcome. This is an utility function, and you most likely
want to use the cross functions.
combineBeeGametes(queen, drones, nProgeny = 1, simParamBee = NULL)
queen |
|
drones |
|
nProgeny |
integer, number of progeny to create per cross |
simParamBee |
|
Pop-class with diploid individuals
# Not exporting this function, since its just a helper
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.