View source: R/Functions_L0_auxilary.R
| getDd | R Documentation |
Level 0 function that returns dominance values of individuals in a caste.
getDd(x, caste = NULL, nInd = NULL, collapse = FALSE, simParamBee = NULL)
getQueenDd(x, collapse = FALSE, simParamBee = NULL)
getFathersDd(x, nInd = NULL, collapse = FALSE, simParamBee = NULL)
getVirginQueensDd(x, nInd = NULL, collapse = FALSE, simParamBee = NULL)
getWorkersDd(x, nInd = NULL, collapse = FALSE, simParamBee = NULL)
getDronesDd(x, nInd = NULL, collapse = FALSE, simParamBee = NULL)
x |
|
caste |
NULL or character, NULL when |
nInd |
numeric, number of individuals to access, if |
collapse |
logical, if the return value should be a single matrix with dominance values of all the individuals |
simParamBee |
|
vector of dominance values when x is
Colony-class and list of vectors of dominance values when
x is MultiColony-class, named by colony id when x
is MultiColony-class
# Not exporting this function, since the theory behind it is not fully developed
getQueenDd(): Access dominance value of the queen
getFathersDd(): Access dominance values of fathers
getVirginQueensDd(): Access dominance values of virgin queens
getWorkersDd(): Access dominance values of workers
getDronesDd(): Access dominance values of drones
dd and
vignette(topic = "QuantitativeGenetics", package = "SIMplyBee")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.