Learn R Programming

SIMplyBee (version 0.4.1)

isGenoHeterozygous: Test if a multilocus genotype is heterozygous

Description

Level 0 function that returns heterozygote status for a multilocus genotype.

Usage

isGenoHeterozygous(x)

Value

logical # Not exporting this function, since its just a helper

Arguments

x

integer or matrix, output from getCsdGeno